==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/MotoristProviderImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/v3/./motoristProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider",
	portName = "motoristProviderPort",
	serviceName = "motoristProvider")
public class MotoristProviderImplementationManager extends AbstractImplementationManager<MotoristProvider> implements MotoristProvider{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public MotoristProviderImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new MotoristProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public MotoristProviderImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new MotoristProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse providemotoristDriver(ProvidemotoristDriverRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providemotoristDriver" ,parameters);
		response = this.getTestImplementation().providemotoristDriver(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("motoristProvider", "motoristProviderPort", "providemotoristDriver", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providemotoristDriver" ,parameters, response);
		return response;
	}


	public fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse providemotorist(ProvidemotoristRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providemotorist" ,parameters);
		response = this.getTestImplementation().providemotorist(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("motoristProvider", "motoristProviderPort", "providemotorist", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providemotorist" ,parameters, response);
		return response;
	}



}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/MotoristProviderImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/management/generated/./motoristProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider",
	portName = "motoristProviderPort",
	serviceName = "motoristProvider")
public class MotoristProviderImplementationManager extends AbstractImplementationManager<MotoristProvider> implements MotoristProvider{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public MotoristProviderImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new MotoristProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public MotoristProviderImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new MotoristProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse providemotoristDriver(ProvidemotoristDriverRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providemotoristDriver" ,parameters);
		response = this.getTestImplementation().providemotoristDriver(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("motoristProvider", "motoristProviderPort", "providemotoristDriver", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristDriverResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providemotoristDriver" ,parameters, response);
		return response;
	}


	public fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse providemotorist(ProvidemotoristRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providemotorist" ,parameters);
		response = this.getTestImplementation().providemotorist(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("motoristProvider", "motoristProviderPort", "providemotorist", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidemotoristResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providemotorist" ,parameters, response);
		return response;
	}



}
